import Logo from "../components/Logo";
import ShowValue from "../components/ShowValue";
import { BarChart, Bar, XAxis, YAxis, Tooltip, CartesianGrid } from "recharts";
import { useEffect, useState } from "react";

let pms3003 = [
  { name: "PM2.5", unit: "μg." },
  { name: "PM1", unit: "μg." },
  { name: "PM10", unit: "μg." },
];
const PMS3003 = () => {
  const [sensor, setSensor] = useState([]);
  useEffect(() => {
    const FetchPMS3003 = async () => {
      const response = await fetch("http://172.20.10.13:60/");
      const data = await response.json();
      let temp = [];
      Object.entries(data).forEach(([key, value]) => {
        if (key !== "name" && key !== "Unit") {
          temp.push({ name: key, value: value });
        }
      });
      setSensor(temp);
    };
    FetchPMS3003();
  }, []);

  return (
    <div
      style={{
        display: "flex",
        flexDirection: "row",
        flexWrap: "wrap",
        justifyContent: "space-evenly",
      }}
    >
      <div>
        <Logo />
        <ShowValue sensor="pm25" tags={pms3003} unit="ppm" />
      </div>
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          justifyContent: "space-around",
        }}
      >
        <Tracking />
        <div>
          <BarChart width={600} height={300} data={sensor}>
            <XAxis dataKey="name" stroke="#8884d8" />
            <YAxis />
            <Tooltip />
            <CartesianGrid stroke="#ccc" strokeDasharray="5 5" />
            <Bar dataKey="value" fill="#8884d8" barSize={30} />
          </BarChart>
        </div>
      </div>
    </div>
  );
};

const Tracking = () => {
  return (
    <div
      style={{
        lineHeight: "1.1",
        paddingLeft: "20px",
      }}
    >
      <h2
        style={{
          fontSize: "3.9rem",
          fontWeight: "900",
          color: "#314d63",
          paddingBottom: "0",
        }}
      >
        PMS3003
        <span
          style={{
            fontSize: "1.5rem",
            fontWeight: "400",
            marginLeft: "10px",
          }}
        >
          (PM2.5, PM1, PM10 Detector)
        </span>
      </h2>
      <h5
        style={{
          paddingTop: "0",
          fontSize: "4.8rem",
          fontWeight: "400",
          letterSpacing: "30px",
          color: "#314d63",
        }}
      >
        TRACKING
      </h5>
    </div>
  );
};

export default PMS3003;
